API reference
=============
Content below is automatically produced from `docstrings` in the sources, and needs more work... 

Core
----
.. currentmodule:: fuefit
.. autosummary::

    pdcalc
    datamodel
    processor

ExcelRunner
-----------
.. currentmodule:: fuefit.excel
.. autosummary::

    FuefitExcelRunner


Tests
-----
.. currentmodule:: fuefit.test
.. autosummary::

    cmdline_test


Module: :mod:`fuefit.datamodel`
-------------------------------
.. automodule:: fuefit.datamodel
    :members:

Module: :mod:`fuefit.processor`
-------------------------------
.. automodule:: fuefit.processor
    :members:

Module: :mod:`fuefit.pdcalc`
----------------------------
.. automodule:: fuefit.pdcalc
    :members:

Module: :mod:`fuefit.excel.FuefitExcelRunner`
---------------------------------------------
.. automodule:: fuefit.excel.FuefitExcelRunner
    :members:

Module: :mod:`fuefit.test.cmdline_test`
---------------------------------------
.. automodule:: fuefit.test.cmdline_test
    :members:

